#
# spec file for package OpenLP
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           OpenLP
Version:        3.1.5
Release:        1.3
Summary:        Open source Church presentation and lyrics projection application
License:        GPL-2.0-only
URL:            https://gitlab.com/openlp/openlp
Source0:        https://get.openlp.org/%{version}/%{name}-%{version}.tar.gz
Source1:        OpenLP-rpmlintrc
Patch0:         suse_corrections.patch
Patch1:         fix-version.patch
BuildRequires:  desktop-file-utils
BuildRequires:  python-rpm-macros
BuildRequires:  fdupes
BuildRequires:  libqt5-linguist
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
BuildRequires:  update-desktop-files
Requires:       hicolor-icon-theme
Requires:       python3-Mako
Requires:       python3-PyICU
Requires:       python3-QtAwesome
Requires:       python3-SQLAlchemy
Requires:       python3-alembic
Requires:       python3-beautifulsoup4
Requires:       python3-chardet
Requires:       python3-dbus-python
Requires:       python3-distro
Requires:       python3-Flask
Requires:       python3-Flask-Cors
Requires:       python3-lxml
Requires:       python3-platformdirs
Requires:       python3-pyenchant
Requires:       python3-pymediainfo >= 2.2
Requires:       python3-qrcode
Requires:       python3-qt5 >= 5.12
Requires:       python3-qtwebengine-qt5
Requires:       python3-requests
Requires:       python3-waitress
Requires:       python3-websockets
Requires(post): shared-mime-info
Requires(postun): shared-mime-info
Recommends:     libreoffice-pyuno
Recommends:     python3-python-vlc
BuildArch:      noarch

%description
OpenLP is a church presentation software, for lyrics projection software,
used to display slides of Songs, Bible verses, videos, images, and
presentations via LibreOffice using a computer and projector.

%prep
%autosetup -p1 -c

# Remove unit tests
rm tests/__init__.py

%build
%python3_pyproject_wheel

# Compile the translation files and copy them to the correct directory
# Presumes you are in the base directory of OpenLP

%install
%python3_pyproject_install

install -m644 -p -D resources/images/openlp-logo-16x16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/openlp.png
install -m644 -p -D resources/images/openlp-logo-32x32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/openlp.png
install -m644 -p -D resources/images/openlp-logo-48x48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/openlp.png
install -m644 -p -D resources/images/openlp-logo.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/openlp.svg

%suse_update_desktop_file -i -r openlp AudioVideo Video Player

mkdir -p %{buildroot}%{_datadir}/openlp/i18n/
for TSFILE in resources/i18n/*.ts; do
    lrelease-qt5 $TSFILE -qm %{buildroot}%{_datadir}/openlp/i18n/`basename $TSFILE .ts`.qm;
done

mkdir -p %{buildroot}%{_datadir}/mime/packages
cp -p resources/openlp.xml %{buildroot}%{_datadir}/mime/packages

# Deduplicate .pyc and .pyo files
%fdupes %{buildroot}%{python_sitelib}

%post
touch --no-create %{_datadir}/icons/hicolor ||:
gtk-update-icon-cache -q %{_datadir}/icons/hicolor 2> /dev/null ||:
update-mime-database %{_datadir}/mime > /dev/null 2>&1 ||:
update-desktop-database > /dev/null 2>&1 ||:

%postun
touch --no-create %{_datadir}/icons/hicolor ||:
gtk-update-icon-cache -q %{_datadir}/icons/hicolor 2> /dev/null ||:
update-mime-database %{_datadir}/mime > /dev/null 2>&1 ||:
update-desktop-database > /dev/null 2>&1 ||:

%files
%license LICENSE
%doc copyright.txt
%{_bindir}/openlp
%{_datadir}/mime/packages/openlp.xml
%{_datadir}/applications/openlp.desktop
%{_datadir}/icons/hicolor
%{_datadir}/openlp
%{python3_sitelib}/openlp/
%{python3_sitelib}/%{name}-%{version}*-info

%changelog
* Fri Dec 27 2024 Cor Blom <cornelis@solcon.nl>
- Update to 3.1.5: there has been a number of releases, details
  can be found at:
  https://openlp.org/blog/
- Add fix-version.patch to set the version at 3.1.5 instead of
  3.1.4
* Sat Mar  2 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 3.1.0: See all the details at
  https://openlp.org/blog/2024/02/29/openlp-310-superb-seth-released
- Update and fix dependencies
* Tue Feb 27 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add dependency on setuptools
* Sat Mar 18 2023 Matej Cepl <mcepl@suse.com>
- Update to 3.0.2:
  The difference is huge and the list of changes is long. Please,
  if you care study whole story on https://openlp.org/blog.
  This particular minor release changed:
  - Only show hash if song book number exists
  - FIX: Missing looping for theme background videos
  - Fix Songs' Topics media manager icon to be the same from the
    Song Maintenance dialog
  - Add ability to return transposed item with service_item
    format to avoid duplicate calls on remote
  - Fix OpenLyrics whitespaces being 'eaten' (again)
  - Fixg service manager's list exception when pressing 'Left'
    keyboard key without any item selected
  - Force the use of SqlAlchemy 1.4 for now
  - Removing login requirement from transpose endpoint
  - Handle verse ranges in BibleServer
  - Fix up loading 2.9.x services
  - Attempt to fix #1287 by checking for both str and bytes, and
    decoding bytes to unicode
  - Add debugging for VLC and fix strange state.
  - Display the closing progress dialog during plugin shutdown
  - Fix an issue with the Worship Center Pro importer
  - Fix white preview display when previewing presentations
  - Fix an issue where the websockets server would try to shut
    down even when -w is supplied
  - Use a simpler approach when creating a tmp file when saving
    service files
* Thu Dec 17 2020 Matej Cepl <mcepl@suse.com>
- nose dependency was actually not needed at all
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sun Apr  9 2017 schrott3000@yahoo.de
- Updated from version 2.4.5 to version 2.4.6
  * Fixed a bug where the author type upgrade was being ignored because it was looking at the wrong table
  * Fixed a bug where the songs_songbooks table was not being created because the if expression was the wrong way round
  * Changed the songs_songbooks migration SQL slightly to take into account a bug that has (hopefully) been fixed
  * Sometimes the timer goes off as OpenLP is shutting down, and the application has already been deleted
  * Fixed opening the data folder (KDE thought the old way was an SMB share)
  * Fixed a problem with the new QMediaPlayer not controlling the playlist anymore
  * Added importing of author types to the OpenLP 2 song importer
  * Fixed a problem with loading Qt's translation files (lp#1676163)
  * Disabled the controls in the shortcut dialog unless a shortcut is actually selected
* Mon Feb 20 2017 schrott3000@yahoo.de
- Updated from version 2.4.4 to version 2.4.5
  * Spinners in Theme Wizard segfault on OS X (lp#1645867)
  * Formatting tags gets included in searchable lyric text (lp#1655988)
  * VideoPsalm import fails due to unexpected format (lp#1652851)
  * OSZL is ignored on save (inconsistent gui) (lp#1660473)
  * Initial "extract song usage data" produces a traceback (lp#1661416)
  * Importing photos does not give focus to OpenLP (lp#1487788)
  * Loop tooltip gets stuck to "Stop playing..." (lp#1512040)
  * Importing Songbeamer songs using latin1 encoding doesn't get decoded correctly (lp#1530597)
  * Typos in songusageplugin.py (lp#1532193)
  * Web remote does not work with newer versions of jQuery (lp#1605009)
  * Missing DB in unmounted disk results in Traceback (lp#1624661)
  * EasySlide importer gets the verse order wrong (lp#1655985)
* Sun Dec  4 2016 schrott3000@yahoo.de
- Updated from version 2.4.3 to version 2.4.4
  * SongSelect import throws attribute exception when importing a song (lp#1629079)
  * Web remote does not work with newer versions of jQuery (lp#1605009)
  * Unable to delete web bibles or more than one bible (lp#1623711)
* Mon Oct  3 2016 schrott3000@yahoo.de
- Updated from version 2.4.2 to version 2.4.3
  * Deleting a songbook throws "song" attribute exception (lp#1600510)
  * Escaping video twice results in traceback (lp#1547964)
  * Service theme selector is missing if theme level is song or Service (lp#1596668)
  * CrossWalk bible list is empty (lp#1599999)
  * Import from SongSelect no longer works (website updated) (lp#1608194)
  * Biblegateway Downloads Amplified Classic instead of Amplified 2015 (lp#1562384)
  * Improper characters in Mediashout import cause traceback (lp#1618489)
* Fri Jul 22 2016 p.drouand@gmail.com
- Add suse_corrections.patch
* Thu Jul  7 2016 schrott3000@yahoo.de
- Updated from version 2.4.1 to version 2.4.2
* Sat Jun 25 2016 schrott3000@yahoo.de
- Updated from version 2.0.5 to version 2.4.1
- Small error corrections
  * Corrected keywords in desktop file
  * Removed shebang from vlc.py
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Tue Jul  1 2014 joseph@mulloy.me
- Updated to 2.0.5 (bnc#884901)
  * Upstream bugfix/stabilization release
  * Final release in the 2.0 branch
  * Change to BibleGateway URL to use legacy web interface
  * Issues with Themes when comparing theme files (lp#719514)
  * Improved error messages with Easy Worship Song Imports (lp#1326664)
  * Allow more than 26 equal verses within a Song (lp#1310523)
  * Handle songs where two optional breaks follow each other (lp#1296104)
  * Improve Database update error handling (lp#1136278)
* Tue Jul  1 2014 joseph@mulloy.me
- Updated to 2.0.5 (bnc#884901)
  * Upstream bugfix/stabilization release
  * Final release in the 2.0 branch
  * Change to BibleGateway URL to use legacy web interface
  * Issues with Themes when comparing theme files (lp#719514)
  * Improved error messages with Easy Worship Song Imports (lp#1326664)
  * Allow more than 26 equal verses within a Song (lp#1310523)
  * Handle songs where two optional breaks follow each other (lp#1296104)
  * Improve Database update error handling (lp#1136278)
* Tue Jul  1 2014 joseph@mulloy.me
- Updated to 2.0.5 (bnc#884901)
  * Upstream bugfix/stabilization release
  * Final release in the 2.0 branch
  * Change to BibleGateway URL to use legacy web interface
  * Issues with Themes when comparing theme files (lp#719514)
  * Improved error messages with Easy Worship Song Imports (lp#1326664)
  * Allow more than 26 equal verses within a Song (lp#1310523)
  * Handle songs where two optional breaks follow each other (lp#1296104)
  * Improve Database update error handling (lp#1136278)
* Mon Jun 30 2014 joseph@mulloy.me
- Updated to 2.0.5 (bnc#884901)
  * Upstream bugfix/stabilization release
  * Final release in the 2.0 branch
  * Change to BibleGateway URL to use legacy web interface
  * Issues with Themes when comparing theme files (lp#719514)
  * Improved error messages with Easy Worship Song Imports (lp#1326664)
  * Allow more than 26 equal verses within a Song. (lp#1310523)
  * Handle songs where two optional breaks follow each other. (lp#1296104)
  * Improve Database update error handling. (lp#1136278)
* Sat Feb 15 2014 joseph@mulloy.me
- Updated to 2.0.4 (bnc#864175)
  * Upstream bugfix/stabilization release
- Bugs fixed in this release
  * lp#1154467: Web download bible db's getting locked
  * lp#1173749: Songs with mismatching formatting tags still throw
    an exception
  * lp#1252477: Changing theme on bible settings tab causes an
    error when saving service
  * lp#1012110: pptviewlib does not accept unicode filename
  * lp#1199639: Formatting tags opened and closed in different
    verses throw an exception
  * lp#1206886: HTTP Server gets deleted
  * lp#1222534: KeyError when "Allow presentation application to be
    overridden" and Spanish language is selected
  * lp#1223841: Transition does not work if texts are the same
  * lp#1225763: Replacing background with video unblank screen even
    if "Blanked to Theme"
  * lp#1251437: BibleGateway importer crashes on non unicode urls
  * lp#1258634: TypeError when saving service from previous versions
    with notes
  * lp#1259606: Clicking Verse Button doesn't alter live slide
  * lp#1266271: Output display returns after pressing esc when
    looping slides
  * lp#1157938: "Alt + Tab" = some pixelated icons and missing icons
  * lp#1211049: Can no long download bible verses
  * lp#1216234: Layout style has not effect when using a second bible
  * lp#1240942: Troubleshooting guide is outdated
  * lp#1265368: [regression] Traceback in web remote
  * lp#1163874: Add Slovak bible to First Run Wizard
* Wed Dec 18 2013 hrvoje.senjan@gmail.com
- Phonon package exists only via provides, so don't make OpenLP
  package require it - provide will go away soon
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Sep 20 2013 jdmulloy@gmail.com
- Update to 2.0.3 (bnc#841394)
  * Fixes regression introduced in 2.0.2 that prevents saving
    service files with notes in them (lp#1216785)
* Fri Aug 30 2013 jdmulloy@gmail.com
- Update to 2.0.2 (bnc#837706):
  * Upstream bugfix/stabilization release
  * Improvements/Bugfixes for UI, Song Importers and more
* Mon Jan  7 2013 alexandre@exatati.com.br
- Update to 2.0.1:
  * Song export and import now works correctly
  * Transparent themes are once again transparent
  * PowerPoint/Impress files with unicode characters in the filename
    can be imported
  * OpenLP is now more usable with the XFCE desktop on Linux
* Fri Dec  7 2012 jdmulloy@gmail.com
- Updated to OpenLP 2.0
  * Stable release of OpenLP 2.0
* Tue Sep 25 2012 jdmulloy@gmail.com
- Updated from version 1.9.11 (2.0 RC1) to version 1.9.12 (2.0 RC2)
  * Includes various bugfixes
- Added rpmlintrc to suppress spurious RPMLINT warnings
- Deleted obsolete patch file uno-path.patch
* Wed Aug  8 2012 jdmulloy@gmail.com
- Bumped version from 1.9.10 (2.0 RC1) to 1.9.11 (2.0 RC2)
- Includes various bugfixes
* Sun Jul  8 2012 jdmulloy@gmail.com
- Bumped version from 1.9.9 to 1.9.10
- Removed uno-path.patch as libreoffice-pyuno has been fixed
- Fixed missing translations bug (lp#1007148)
- Fixed error in %%suse_update_desktop_file argument order
* Sat Mar 24 2012 jdmulloy@gmail.com
- Bumped version from 1.9.8 to 1.9.9
- Removed openlp-1.9.8-impress-segfault-backport.patch because the
  upstream release incorporates the fix
* Mon Mar 19 2012 jdmulloy@gmail.com
- Added python-xdg as a dependency so that data files are always
  stored in ~/.local/share/openlp
* Sun Mar 11 2012 jdmulloy@gmail.com
- Changed download_files service mode to localonly to comply with
  Factory rules
* Tue Mar  6 2012 jdmulloy@gmail.com
- Added openlp-1.9.8-impress-segfault-backport.patch which
  backports fix from upstream to bnc#748241.
  Patch can be removed in the next release from upstream
* Thu Feb 23 2012 saschpe@suse.de
- Actually add a tarball ;-)
- Spec file cleanup:
  * Adjust dependency names to what we currently have in d:l:p / Factory
  * Simplified macro usage
* Wed Feb 22 2012 jdmulloy@gmail.com
- Removed download service and manually uploaded tarball for
  submission to Factory
* Tue Feb 21 2012 jdmulloy@gmail.com
- Cleaned up spec file to make it more readable
- Added conditional to prevent application of uno-path patch on
  openSUSE > 12.1
  * Bug in libreoffice-pyuno is fixed in Factory (12.2)
* Sun Dec 25 2011 jdmulloy@gmail.com
- Bumped OpenLP version from 1.9.7 to 1.9.8
- Cleaned up spec file
* Mon Dec  5 2011 jdmulloy@gmail.com
- Added uno-path.patch to make 'import uno' work
  * This patch, patches the two files that call 'import uno'.
  It appends the appropriate path to sys.path so that python can
  find the uno module.
- Added %%fdupes to %%install section to resolve RPMLINT warnings
* Thu Dec  1 2011 jdmulloy@gmail.com
- Changed Release: tag to use %%mkrel
* Wed Nov 30 2011 jdmulloy@gmail.com
- Removed unessecary dependencies
  * Removed libreoffice-graphicfilter and libreoffice-headless which
  are part of libreoffice in OpenSuse
  * Removed python-openoffice as it is not actually used by OpenLP
- Corrected dependency names
  * Corrected capitalization for python-beautifulsoup
  * Changed python-migrate to python-sqlalchemy-migrate
- Added libreoffice-pyuno to dependency list
* Mon Nov 28 2011 alexandre@exatati.com.br
- License on SPDX format;
- Fix Group in spec file.
* Thu Nov 24 2011 alexandre@exatati.com.br
- Reworked spec file;
- Work start from home:jdmulloy:openlp.
